@@ -1,3 +1,5 @@
+# coding: utf-8
+
 import unittest
 
 from livefyre.src.utils import is_valid_full_url
@@ -10,4 +12,6 @@ class UtilsTestCase(unittest.TestCase):
         self.assertTrue(is_valid_full_url("http://test.com"))
         self.assertTrue(is_valid_full_url("https://test.com/"))
         self.assertTrue(is_valid_full_url("ftp://test.com/"))
+        self.assertTrue(is_valid_full_url("http://清华大学.cn"))
+        self.assertTrue(is_valid_full_url("http://www.mysite.com/myresumé.html"))
         self.assertTrue(is_valid_full_url("https://test.com/path/test.-_~!$&'()*+,=:@/dash"))
